BufferUsage

Enum BufferUsage 

#[repr(u32)]
pub enum BufferUsage { MapReap = 0, MapWrite = 1, CopySrc = 2, CopyDst = 3, Index = 4, Vertex = 5, Uniform = 6, Storage = 7, Indirect = 8, QueryResolve = 9, BlasInput = 10, TlasInput = 11, }

Variants



MapReap = 0



MapWrite = 1



CopySrc = 2



CopyDst = 3



Index = 4



Vertex = 5



Uniform = 6



Storage = 7



Indirect = 8



QueryResolve = 9



BlasInput = 10



TlasInput = 11

Implementations

Source

impl BufferUsage

pub const ALL: [Self; 12]

Can’t be indexed with Self::X as usize because all the used bit flags are not necessary contiguous

pub const BITS: [BufferUsageFlags; 12]

Can’t be indexed with Self::X as usize because all the used bit flags are not necessary contiguous

pub const fn index(self) -> usize

The bit index

pub const fn flags(self) -> BufferUsageFlags

pub const fn bits(self) -> u32

pub fn from_index(index: u32) -> Option<Self>

pub unsafe fn from_index_unchecked(index: u32) -> Option<Self>

pub fn from_flags(flags: BufferUsageFlags) -> Option<Self>

pub unsafe fn from_flags_unchecked(flags: BufferUsageFlags) -> Self

pub fn from_bits(bits: u32) -> Option<Self>

pub unsafe fn from_bits_unchecked(bits: u32) -> Self